library('data.table')
library('seeker')
doParallel::registerDoParallel()

study = 'PRJNA297287'
dir.create(study)
fastqDir = file.path(study, 'fastq')
quantDir = file.path(study, 'salmon_output')

metadata = setDT(getMetadata(study))
readr::write_csv(metadata, file.path(study, 'metadata_ena.csv'))

# has to be downloaded manually
metadataSra = setDT(readr::read_tsv(file.path(study, 'SraRunTable.txt')))

metadata = merge(metadata, metadataSra,
                 by.x = c('sample_accession', 'secondary_sample_accession',
                          'experiment_accession', 'run_accession'),
                 by.y = c('BioSample', 'SRA_Sample', 'Experiment', 'Run'))
metadata = metadata[feeding == 'Ad Libitum' & genotype == 'Wild type']

fastqResult = getFastq(metadata$fastq_aspera, fastqDir)
metadata$fastq_local = fastqResult$localFilepaths

salmon(metadata$fastq_local, metadata$secondary_sample_accession, quantDir,
       indexPath = '~/transcriptomes/mus_musculus_transcripts')

tx2gene = getTx2gene('mmusculus_gene_ensembl')
tximport(file.path(quantDir, sort(unique(metadata$secondary_sample_accession))),
         tx2gene, file.path(study, 'tximport_output.rds'))
