source(file.path('scripts', 'sim_setup.R'))
source(file.path('source', 'jtk_api.R'))

featureGroups = CJ(amp = seq(0, 0.5, 0.05), base = c(6, 8, 10))
intervals = 2:4

rhyAuc = foreach(interval = intervals, .combine = rbind) %dopar% {
  simData = simphony(featureGroups, nFeatures = 2e4, interval = interval,
                     nReps = 1, family = 'negbinom')

  sampleMetadata = simData$sampleMetadata

  abundData = log2(simData$abundData + 1)
  nTimePoints = length(unique(sampleMetadata[, time]))
  nReps = ncol(abundData) / nTimePoints
  period = 24

  rhyJtk = runJTK(abundData, nTimePoints, nReps, period, interval)
  rhyJtk = merge(rhyJtk, simData$featureMetadata, by = 'feature')

  rhyNeg = rhyJtk[amp0 == 0]

  jtkAuc = foreach(groupNow = unique(rhyJtk[amp0 > 0, group]), .combine = rbind) %dopar% {
    rhyPos = rhyJtk[group == groupNow]
    rhyNow = rbind(rhyNeg, rhyPos)
    rocprc = evalmod(scores = -log(rhyNow$ADJ.P), labels = rhyNow$amp0 > 0)
    aucNow = auc(rocprc)$aucs[1]
    data.table(group = groupNow, auc = aucNow, interval = interval)}
  jtkAuc = merge(jtkAuc, unique(simData$featureMetadata[, .(group, amp0, base0)]),
                 by = 'group')}

########################################

pInterval = ggplot(rhyAuc[base0 == 8]) +
  geom_point(aes(x = amp0, y = auc, fill = factor(interval)), shape = 21, size = 2) +
  labs(x = 'Rhythm amplitude\n(log2 counts)', y = 'AUROC',
       fill = 'Interval (h)') +
  scale_x_continuous(limits = c(NA, 0.5), breaks = seq(0.1, 0.5, 0.1)) +
  scale_y_continuous(limits = c(NA, 1)) +
  scale_fill_brewer(type = 'qual', palette = 'Blues', direction = -1)

########################################

pBase = ggplot(rhyAuc[interval == 2]) +
  geom_point(aes(x = amp0, y = auc, fill = factor(base0)), shape = 21, size = 2) +
  labs(x = 'Rhythm amplitude\n(log2 counts)', y = 'AUROC',
       fill = 'Baseline\n(log2 counts)') +
  scale_x_continuous(limits = c(NA, 0.5), breaks = seq(0.1, 0.5, 0.1)) +
  scale_y_continuous(limits = c(NA, 1)) +
  scale_fill_brewer(type = 'qual', palette = 'Blues', direction = -1)

########################################

p = plot_grid(pInterval, pBase, labels = 'AUTO',
              nrow = 1, align = 'hv', axis = 'tblr')

ggplot2::ggsave(file.path(resultDir, 'sim_detection_auroc.pdf'), plot = p,
                height = 2.5, width = 7)
ggplot2::ggsave(file.path(resultDir, 'sim_detection_auroc.png'), plot = p,
                height = 2.5, width = 7)

########################################

featureGroups = CJ(amp = seq(0, 0.5, 0.05), base = c(6, 8, 10))
simData = simphony(featureGroups, nFeatures = 2e4, interval = 2, nReps = 1,
                   family = 'negbinom')

simData$featureMetadata[, baseFac := factor(paste('Baseline:', base0),
                                            unique(paste('Baseline:', base0)))]
simData$featureMetadata[, ampFac := factor(paste('Rhythm amp:', amp0),
                                           unique(paste('Rhythm amp:', amp0)))]

fmSubset = simData$featureMetadata[amp0 %in% c(0, 0.5), .SD[1], by = .(base0, amp0)]

dObs = mergeSimData(simData, fmSubset$feature)
dExp = getExpectedAbund(fmSubset, times = seq(0, 48, 0.1))

pExample = ggplot(dObs) +
  facet_grid(ampFac ~ baseFac, scales = 'fixed') +
  geom_line(aes(x = time, y = log2(2^mu + 1)), size = 0.25, data = dExp) +
  geom_point(aes(x = time, y = log2(abund + 1)), shape = 21) +
  labs(x = 'Time (h)', y = expression(log[2](counts+1))) +
  scale_x_continuous(limits = c(0, 48), breaks = seq(0, 48, 8)) +
  scale_y_continuous(breaks = seq(0, 10, 2))

########################################

dObsNow = mergeSimData(simData, simData$featureMetadata[amp0 == 0, feature])
dObsSummary = dObsNow[, .(sdObs = sd(log2(abund + 1))), by = base0]

pSd = ggplot(dObsSummary) +
  geom_point(aes(x = factor(base0), y = sdObs), size = 3) +
  labs(x = expression('Baseline '*(log[2]~counts)),
       y = expression(SD(log[2](counts+1))))

########################################

wd = 0.4
ht = 0.4
p = ggdraw() +
  draw_plot(pExample, y = ht, height = 1 - ht) +
  draw_plot(pSd, width = wd, height = ht) +
  draw_plot_label(c('A', 'B'), y = c(1, ht), size = 14)

ggplot2::ggsave(file.path(resultDir, 'sim_detection_supp.pdf'),
                plot = p, width = 5.5, height = 6)
ggplot2::ggsave(file.path(resultDir, 'sim_detection_supp.png'),
                plot = p, width = 5.5, height = 6)
