source(file.path('scripts', 'sim_setup.R'))

times = seq(0, 24, 0.1)
timeRange = c(0, 48)
featureGroupsList = list(data.table(amp = c(1, 2, 2), phase = c(0, -3, 0), period = c(24, 24, 24)),
                         data.table(amp = c(3, 2, 2), phase = c(0,  3, 0), period = c(24, 24, 30)))

simData = simphony(featureGroupsList, nFeatures = 3, interval = 4, nReps = 2,
                   family = 'negbinom', timeRange = timeRange)

nbinomObs = mergeSimData(simData, unique(simData$featureMetadata$feature))
nbinomObs[, abund := log2(abund + 1)]
nbinomObs[, condLabel := ifelse(cond == 1, 'A', 'B')]

nbinomExp = getExpectedAbund(simData$featureMetadata,
                             times = seq(timeRange[1], timeRange[2], 0.25))
nbinomExp[, condLabel := ifelse(cond == 1, 'A', 'B')]

########################################

p = ggplot(nbinomObs) +
  facet_wrap(~ feature) +
  geom_line(aes(x = time, y = log2(2 ^ mu + 1), color = condLabel), size = 0.5,
            data = nbinomExp) +
  geom_point(aes(x = time, y = abund, fill = condLabel, shape = condLabel)) +
  labs(x = 'Time (h)', y = expression('log'[2] * '(counts+1)'),
       fill = 'Condition', shape = 'Condition') +
  scale_x_continuous(limits = timeRange, breaks = seq(timeRange[1], timeRange[2], 8)) +
  scale_fill_brewer(type = 'qual', palette = 'Paired') +
  scale_color_brewer(type = 'qual', palette = 'Paired', guide = FALSE) +
  scale_shape_manual(values = c(21, 22))

ggplot2::ggsave(file.path(resultDir, 'sim_timecourse_diffrhy.pdf'), plot = p,
                height = 2, width = 7)
ggplot2::ggsave(file.path(resultDir, 'sim_timecourse_diffrhy.png'), plot = p,
                height = 2, width = 7)
