source(file.path('scripts', 'sim_setup.R'))

maxAmp = 4
minAmp = 1
maxPhase = 12
nFeatures = 200
timeRange = c(0, 48)
nReps = 1
interval = 2

featureGroups = data.table(amp = seq(minAmp, maxAmp, (maxAmp - minAmp) / nFeatures),
                           phase = seq(0, maxPhase, maxPhase / nFeatures))
simData = simphony(featureGroups, timeRange = timeRange, nReps = nReps,
                   interval = interval, nFeatures = nFeatures)

m = mergeSimData(simData)
m[, abundCrop := ifelse(abund < (-maxAmp), -maxAmp,
                        ifelse(abund > maxAmp, maxAmp, abund))]

p = ggplot(m) +
  geom_tile(aes(x = time, y = feature, fill = abundCrop)) +
  labs(x = 'Time (h)', y = 'Gene', fill = 'Expression\n(a.u.)') +
  scale_x_continuous(limits = timeRange - 1,
                     breaks = seq(timeRange[1], timeRange[2], 8)) +
  scale_fill_gradient2(low = '#ca0020', mid = '#f7f7f7', high = '#0571b0') +
  theme_minimal() +
  theme(axis.text = element_text(color = 'black'),
        axis.text.y = element_blank(),
        legend.margin = margin(t = 0, r = 0, b = 0, l = 0, unit = 'cm'),
        panel.grid = element_blank())

ggsave(file.path(resultDir, 'sim_timecourse_heatmap.pdf'), p, width = 3.5, height = 3)
ggsave(file.path(resultDir, 'sim_timecourse_heatmap.png'), p, width = 3.5, height = 3)
