source(file.path('scripts', 'sim_setup.R'))

rhyLinExp = function(x, period = 2 * pi, xFrac = 0.75, yFrac = 0.9) {
  h = period * (1 - xFrac) / (-log(1 - yFrac))
  xMod = x %% period
  y1 = (xMod < (period * xFrac)) * (yFrac / xFrac / period * xMod + 1 - yFrac)
  y2 = (xMod >= (period * xFrac)) * exp(-(xMod - period * xFrac) / h)
  y = y1 + y2 - yFrac / 2
  return(y)}

rhyFuncs = c(sin, sin, sin, rhyLinExp)
rhyFuncLabels = c('Sinusoid', 'Decreasing\namplitude',
                  'Increasing\nbaseline', 'Non-sinusoid')
featureGroups = data.table(rhyFunc = rhyFuncs,
                           rhyFuncLabel = factor(rhyFuncLabels, rhyFuncLabels))

timeRange = c(0, 48)
interval = 3
times = seq(timeRange[1], timeRange[2], 0.1)
quants = 0.45 * c(-1, 1) + 0.5

########################################
# gaussian

featureGroupsNow = copy(featureGroups)
initialAmp = 4
ampGauss = c(function(x) initialAmp,
             function(x) initialAmp * 2 ^ (-x / 24),
             function(x) initialAmp,
             function(x) initialAmp)
baseGauss = c(function(x) 0,
              function(x) 0,
              function(x) -2 + x / 12,
              function(x) 0)
featureGroupsNow[, amp := ampGauss]
featureGroupsNow[, base := baseGauss]

simData = simphony(featureGroupsNow, nFeatures = 4, interval = interval,
                   family = 'gaussian', timeRange = timeRange)

gaussObs = mergeSimData(simData, simData$featureMetadata$feature)

gaussExp = getExpectedAbund(simData$featureMetadata, times = times)
gaussExp[, lower := qnorm(quants[1], mean = mu, sd = sd)]
gaussExp[, upper := qnorm(quants[2], mean = mu, sd = sd)]

gaussPlot = ggplot(gaussExp) +
  facet_grid(rhyFuncLabel ~ ., scales = 'free_y') +
  geom_ribbon(aes(x = time, ymin = lower, ymax = upper), fill = 'gray85') +
  geom_line(aes(x = time, y = mu), size = 0.25) +
  geom_point(aes(x = time, y = abund), shape = 21, data = gaussObs) +
  labs(x = 'Time (h)', y = 'Expression (a.u.)', title = 'Gaussian') +
  scale_x_continuous(limits = timeRange, breaks = seq(timeRange[1], timeRange[2], 8))

########################################
# negative binomial

featureGroupsNow = copy(featureGroups)
initialAmp = 2
ampNegbinom = c(function(x) initialAmp,
                function(x) initialAmp * 2 ^ (-x / 24),
                function(x) initialAmp,
                function(x) initialAmp)
baseNegbinom = c(function(x) 6,
                 function(x) 6,
                 function(x) 4 + x / 12,
                 function(x) 6)
featureGroupsNow[, amp := ampNegbinom]
featureGroupsNow[, base := baseNegbinom]

simData = simphony(featureGroupsNow, nFeatures = 4, interval = interval,
                   family = 'negbinom', timeRange = timeRange)

nbinomObs = mergeSimData(simData, simData$featureMetadata$feature)
nbinomObs[, abund := log2(abund + 1)]

nbinomExp = getExpectedAbund(simData$featureMetadata, times = times)
nbinomExp[, mu := 2^mu]
nbinomExp[, lower := log2(qnbinom(quants[1], mu = mu, size = 1 / dispFunc[[1]](mu)) + 1),
          by = 1:nrow(nbinomExp)]
nbinomExp[, upper := log2(qnbinom(quants[2], mu = mu, size = 1 / dispFunc[[1]](mu)) + 1),
          by = 1:nrow(nbinomExp)]

nbinomPlot = ggplot(nbinomExp) +
  facet_grid(rhyFuncLabel ~ ., scales = 'free_y') +
  geom_ribbon(aes(x = time, ymin = lower, ymax = upper), fill = 'gray85') +
  geom_line(aes(x = time, y = log2(mu + 1)), size = 0.25) +
  geom_point(aes(x = time, y = abund), shape = 21, data = nbinomObs) +
  labs(x = 'Time (h)', y = expression(log[2] * (counts + 1)),
       title = 'Negative binomial') +
  scale_x_continuous(limits = timeRange, breaks = seq(timeRange[1], timeRange[2], 8))

########################################

joinedPlot = plot_grid(gaussPlot, nbinomPlot, labels = 'AUTO')
ggsave(file.path(resultDir, 'sim_timecourse_rhy.pdf'), plot = joinedPlot,
       height = 5, width = 5)
ggsave(file.path(resultDir, 'sim_timecourse_rhy.png'), plot = joinedPlot,
       height = 5, width = 5)
